@@ -6,22 +6,13 @@ from typing import List, Optional, Union
 
 from packaging.version import Version
 
-from commitizen.defaults import (
-    MAJOR,
-    MINOR,
-    PATCH,
-    bump_map,
-    bump_message,
-    bump_pattern,
-)
+from commitizen.defaults import MAJOR, MINOR, PATCH, bump_message
 from commitizen.exceptions import CurrentVersionNotFoundError
 from commitizen.git import GitCommit
 
 
 def find_increment(
-    commits: List[GitCommit],
-    regex: str = bump_pattern,
-    increments_map: Union[dict, OrderedDict] = bump_map,
+    commits: List[GitCommit], regex: str, increments_map: Union[dict, OrderedDict]
 ) -> Optional[str]:
 
     if isinstance(increments_map, dict):
@@ -141,7 +132,7 @@ def generate_version(
 
 def update_version_in_files(
     current_version: str, new_version: str, files: List[str], *, check_consistency=False
-):
+) -> None:
     """Change old version to the new one in every file given.
 
     Note that this version is not the tag formatted one.
@@ -205,7 +196,7 @@ def _version_to_regex(version: str):
     return re.compile(f"{clean_regex}")
 
 
-def create_tag(version: Union[Version, str], tag_format: Optional[str] = None):
+def create_tag(version: Union[Version, str], tag_format: Optional[str] = None) -> str:
     """The tag and the software version might be different.
 
     That's why this function exists.
